Obtain similarity for two signature matrix, their rows (features) must match.
sig_get_similarity(sig1, sig2, type = c("cos", "cor"))signature 1, result of sig_extract function or
a data.frame which rows are features and columns are signatures
(colnames are necessary).
signature 2, result of sig_extract function or
a data.frame which rows are features and columns are signatures
(colnames are necessary).
could be "cos" (default, cosine similarity) or "cor" (correlation).
a matrix which rownames from sig1 and colnames from sig2.
Other signature analysis series function: sig_assign_samples,
sig_estimate, sig_extract,
sig_get_activity,
sig_get_correlation,
sig_prepare,
sig_summarize_subtypes